#include <pygobject.h>

void gtkwidgets_register_classes (PyObject *d);
extern PyMethodDef gtkwidgets_functions[];
 
DL_EXPORT(void)
init_gtkwidgets(void)
{
    PyObject *m, *d;

    init_pygobject ();

    m = Py_InitModule ("ubuntuone._gtkwidgets", gtkwidgets_functions);
    d = PyModule_GetDict (m);

    gtkwidgets_register_classes (d);

    if (PyErr_Occurred ()) {
        Py_FatalError ("can't initialise module ubuntuone._gtkwidgets");
    }
}
